pub enum IPolicyRegistryErrors {
NonPayable(NonPayable),
Unauthorized(Unauthorized),
PolicyNotFound(PolicyNotFound),
IncompatiblePolicyType(IncompatiblePolicyType),
ZeroAddress(ZeroAddress),
BatchSizeTooLarge(BatchSizeTooLarge),
NoPendingAdmin(NoPendingAdmin),
ChildPoliciesOutsideOfRange(ChildPoliciesOutsideOfRange),
InvalidChildPolicy(InvalidChildPolicy),
}base only.Expand description
Container for all the IPolicyRegistry custom errors.
Variants
NonPayable(NonPayable)
PolicyNotFound(PolicyNotFound)
IncompatiblePolicyType(IncompatiblePolicyType)
ZeroAddress(ZeroAddress)
BatchSizeTooLarge(BatchSizeTooLarge)
NoPendingAdmin(NoPendingAdmin)
ChildPoliciesOutsideOfRange(ChildPoliciesOutsideOfRange)
InvalidChildPolicy(InvalidChildPolicy)
Implementations
Sourceimpl IPolicyRegistryErrors
impl IPolicyRegistryErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IPolicyRegistryErrors
impl IPolicyRegistryErrors
Sourcepub fn non_payable() -> Self
pub fn non_payable() -> Self
Creates a NonPayable error.
error NonPayable()Creates a Unauthorized error.
error Unauthorized()Sourcepub fn policy_not_found() -> Self
pub fn policy_not_found() -> Self
Creates a PolicyNotFound error.
error PolicyNotFound()Sourcepub fn incompatible_policy_type() -> Self
pub fn incompatible_policy_type() -> Self
Creates a IncompatiblePolicyType error.
error IncompatiblePolicyType()Sourcepub fn zero_address() -> Self
pub fn zero_address() -> Self
Creates a ZeroAddress error.
error ZeroAddress()Sourcepub fn batch_size_too_large(max_batch_size: U256) -> Self
pub fn batch_size_too_large(max_batch_size: U256) -> Self
Creates a BatchSizeTooLarge error.
error BatchSizeTooLarge(uint256)Sourcepub fn no_pending_admin() -> Self
pub fn no_pending_admin() -> Self
Creates a NoPendingAdmin error.
error NoPendingAdmin()Sourcepub fn child_policies_outside_of_range() -> Self
pub fn child_policies_outside_of_range() -> Self
Creates a ChildPoliciesOutsideOfRange error.
error ChildPoliciesOutsideOfRange()Sourcepub fn invalid_child_policy(child_policy_id: u64) -> Self
pub fn invalid_child_policy(child_policy_id: u64) -> Self
Creates a InvalidChildPolicy error.
error InvalidChildPolicy(uint64)Trait Implementations
Sourceimpl Clone for IPolicyRegistryErrors
impl Clone for IPolicyRegistryErrors
Sourcefn clone(&self) -> IPolicyRegistryErrors
fn clone(&self) -> IPolicyRegistryErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl SolInterface for IPolicyRegistryErrors
impl SolInterface for IPolicyRegistryErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_with_config(
selector: [u8; 4],
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self>
fn abi_decode_raw_with_config( selector: [u8; 4], data: &[u8], config: AbiDecoderConfig, ) -> Result<Self>
Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreAuto Trait Implementations
impl Freeze for IPolicyRegistryErrors
impl RefUnwindSafe for IPolicyRegistryErrors
impl Send for IPolicyRegistryErrors
impl Sync for IPolicyRegistryErrors
impl Unpin for IPolicyRegistryErrors
impl UnsafeUnpin for IPolicyRegistryErrors
impl UnwindSafe for IPolicyRegistryErrors